=== modified file 'drizzled/field/blob.cc'
--- drizzled/field/blob.cc	2009-12-09 00:33:01 +0000
+++ drizzled/field/blob.cc	2009-12-09 01:28:00 +0000
@@ -40,7 +40,7 @@
 /****************************************************************************
 ** blob type
 ** A blob is saved as a length and a pointer. The length is stored in the
-** packlength slot and may be from 1-4.
+** packlength slot and is sizeof(uint32_t) (4 bytes)
 ****************************************************************************/
 
 Field_blob::Field_blob(unsigned char *ptr_arg,
@@ -50,12 +50,11 @@
                        TableShare *share,
                        const CHARSET_INFO * const cs)
   :Field_str(ptr_arg,
-             blob_pack_length_to_max_length(4),
+             blob_pack_length_to_max_length(sizeof(uint32_t)),
              null_ptr_arg,
              null_bit_arg,
              field_name_arg,
-             cs),
-   packlength(4)
+             cs)
 {
   flags|= BLOB_FLAG;
   share->blob_fields++;
@@ -63,115 +62,70 @@
 }
 
 void Field_blob::store_length(unsigned char *i_ptr,
-                              uint32_t i_packlength,
                               uint32_t i_number,
                               bool low_byte_first)
 {
 #ifndef WORDS_BIGENDIAN
   (void)low_byte_first;
 #endif
-  switch (i_packlength) {
-  case 1:
-    i_ptr[0]= (unsigned char) i_number;
-    break;
-  case 2:
-#ifdef WORDS_BIGENDIAN
-    if (low_byte_first)
-    {
-      int2store(i_ptr,(unsigned short) i_number);
-    }
-    else
-#endif
-      shortstore(i_ptr,(unsigned short) i_number);
-    break;
-  case 3:
-    int3store(i_ptr,i_number);
-    break;
-  case 4:
-#ifdef WORDS_BIGENDIAN
-    if (low_byte_first)
-    {
-      int4store(i_ptr,i_number);
-    }
-    else
-#endif
-      longstore(i_ptr,i_number);
+
+#ifdef WORDS_BIGENDIAN
+  if (low_byte_first)
+  {
+    int4store(i_ptr,i_number);
   }
+  else
+#endif
+    longstore(i_ptr,i_number);
 }
 
 
-void Field_blob::store_length(unsigned char *i_ptr, uint32_t i_packlength,
-                  uint32_t i_number)
+void Field_blob::store_length(unsigned char *i_ptr, uint32_t i_number)
 {
-  store_length(i_ptr, i_packlength, i_number, table->s->db_low_byte_first);
+  store_length(i_ptr, i_number, table->s->db_low_byte_first);
 }
 
 
 uint32_t Field_blob::get_length(const unsigned char *pos,
-                                uint32_t packlength_arg,
                                 bool low_byte_first)
 {
 #ifndef WORDS_BIGENDIAN
   (void)low_byte_first;
 #endif
-  switch (packlength_arg) {
-  case 1:
-    return (uint32_t) pos[0];
-  case 2:
-    {
-      uint16_t tmp;
-#ifdef WORDS_BIGENDIAN
-      if (low_byte_first)
-	tmp=sint2korr(pos);
-      else
-#endif
-	shortget(tmp,pos);
-      return (uint32_t) tmp;
-    }
-  case 3:
-    return (uint32_t) uint3korr(pos);
-  case 4:
-    {
-      uint32_t tmp;
-#ifdef WORDS_BIGENDIAN
-      if (low_byte_first)
-	tmp=uint4korr(pos);
-      else
-#endif
-	longget(tmp,pos);
-      return (uint32_t) tmp;
-    }
-  }
-  return 0;					// Impossible
+  uint32_t tmp;
+#ifdef WORDS_BIGENDIAN
+  if (low_byte_first)
+    tmp=uint4korr(pos);
+  else
+#endif
+    longget(tmp,pos);
+  return (uint32_t) tmp;
 }
 
 
 uint32_t Field_blob::get_packed_size(const unsigned char *ptr_arg,
                                 bool low_byte_first)
 {
-  return packlength + get_length(ptr_arg, packlength, low_byte_first);
+  return sizeof(uint32_t) + get_length(ptr_arg, low_byte_first);
 }
 
 
 uint32_t Field_blob::get_length(uint32_t row_offset)
 {
-  return get_length(ptr+row_offset, this->packlength,
-                    table->s->db_low_byte_first);
+  return get_length(ptr+row_offset, table->s->db_low_byte_first);
 }
 
 
 uint32_t Field_blob::get_length(const unsigned char *ptr_arg)
 {
-  return get_length(ptr_arg, this->packlength, table->s->db_low_byte_first);
+  return get_length(ptr_arg, table->s->db_low_byte_first);
 }
 
 
 /**
   Put a blob length field into a record buffer.
 
-  Depending on the maximum length of a blob, its length field is
-  put into 1 to 4 bytes. This is a property of the blob object,
-  described by 'packlength'.
+  Blob length is always stored in sizeof(uint32_t) (4 bytes)
 
   @param pos                 Pointer into the record buffer.
   @param length              The length value to put.
@@ -179,20 +133,7 @@
 
 void Field_blob::put_length(unsigned char *pos, uint32_t length)
 {
-  switch (packlength) {
-  case 1:
-    *pos= (char) length;
-    break;
-  case 2:
-    int2store(pos, length);
-    break;
-  case 3:
-    int3store(pos, length);
-    break;
-  case 4:
     int4store(pos, length);
-    break;
-  }
 }
 
 
@@ -219,7 +160,7 @@
     if (!String::needs_conversion(length, cs, field_charset, &dummy_offset))
     {
       Field_blob::store_length(length);
-      memmove(ptr+packlength, &from, sizeof(char*));
+      memmove(ptr+sizeof(uint32_t), &from, sizeof(char*));
       return 0;
     }
     if (tmpstr.copy(from, length, cs))
@@ -246,7 +187,7 @@
 
   Field_blob::store_length(copy_length);
   tmp= value.ptr();
-  memmove(ptr+packlength, &tmp, sizeof(char*));
+  memmove(ptr+sizeof(uint32_t), &tmp, sizeof(char*));
 
   if (check_string_copy_error(this, well_formed_error_pos,
                               cannot_convert_error_pos, from + length, cs))
@@ -288,7 +229,7 @@
 
   ASSERT_COLUMN_MARKED_FOR_READ;
 
-  memcpy(&blob,ptr+packlength,sizeof(char*));
+  memcpy(&blob,ptr+sizeof(uint32_t),sizeof(char*));
   if (!blob)
     return 0.0;
   length= get_length(ptr);
@@ -304,7 +245,7 @@
 
   ASSERT_COLUMN_MARKED_FOR_READ;
 
-  memcpy(&blob,ptr+packlength,sizeof(char*));
+  memcpy(&blob,ptr+sizeof(uint32_t),sizeof(char*));
   if (!blob)
     return 0;
   uint32_t length=get_length(ptr);
@@ -318,7 +259,7 @@
 
   ASSERT_COLUMN_MARKED_FOR_READ;
 
-  memcpy(&blob,ptr+packlength,sizeof(char*));
+  memcpy(&blob,ptr+sizeof(uint32_t),sizeof(char*));
   if (!blob)
     val_ptr->set("",0,charset());	// A bit safer than ->length(0)
   else
@@ -334,7 +275,7 @@
 
   ASSERT_COLUMN_MARKED_FOR_READ;
 
-  memcpy(&blob, ptr+packlength, sizeof(const unsigned char*));
+  memcpy(&blob, ptr+sizeof(uint32_t), sizeof(const unsigned char*));
   if (!blob)
   {
     blob= "";
@@ -362,8 +303,8 @@
                         uint32_t max_length)
 {
   unsigned char *blob1,*blob2;
-  memcpy(&blob1,a_ptr+packlength,sizeof(char*));
-  memcpy(&blob2,b_ptr+packlength,sizeof(char*));
+  memcpy(&blob1,a_ptr+sizeof(uint32_t),sizeof(char*));
+  memcpy(&blob2,b_ptr+sizeof(uint32_t),sizeof(char*));
   uint32_t a_len= get_length(a_ptr), b_len= get_length(b_ptr);
   set_if_smaller(a_len, max_length);
   set_if_smaller(b_len, max_length);
@@ -377,8 +318,8 @@
   char *a,*b;
   uint32_t diff;
   uint32_t a_length,b_length;
-  memcpy(&a,a_ptr+packlength,sizeof(char*));
-  memcpy(&b,b_ptr+packlength,sizeof(char*));
+  memcpy(&a,a_ptr+sizeof(uint32_t),sizeof(char*));
+  memcpy(&b,b_ptr+sizeof(uint32_t),sizeof(char*));
 
   a_length= get_length(a_ptr);
 
@@ -460,7 +401,7 @@
 {
   unsigned char *blob1;
   uint32_t blob_length=get_length(ptr);
-  memcpy(&blob1,ptr+packlength,sizeof(char*));
+  memcpy(&blob1,ptr+sizeof(uint32_t),sizeof(char*));
   const CHARSET_INFO * const cs= charset();
   uint32_t local_char_length= max_key_length / cs->mbmaxlen;
   local_char_length= my_charpos(cs, blob1, blob1+blob_length,
@@ -480,7 +421,7 @@
 uint32_t Field_blob::sort_length() const
 {
   return (uint32_t) (current_session->variables.max_sort_length +
-                   (field_charset == &my_charset_bin ? 0 : packlength));
+                     (field_charset == &my_charset_bin ? 0 : sizeof(uint32_t)));
 }
 
 void Field_blob::sort_string(unsigned char *to,uint32_t length)
@@ -499,25 +440,12 @@
       /*
         Store length of blob last in blob to shorter blobs before longer blobs
       */
-      length-= packlength;
+      length-= sizeof(uint32_t); // size of stored blob length
       pos= to+length;
 
-      switch (packlength) {
-      case 1:
-        *pos= (char) blob_length;
-        break;
-      case 2:
-        mi_int2store(pos, blob_length);
-        break;
-      case 3:
-        mi_int3store(pos, blob_length);
-        break;
-      case 4:
-        mi_int4store(pos, blob_length);
-        break;
-      }
+      mi_int4store(pos, blob_length);
     }
-    memcpy(&blob,ptr+packlength,sizeof(char*));
+    memcpy(&blob,ptr+sizeof(uint32_t),sizeof(char*));
 
     blob_length=my_strnxfrm(field_charset,
                             to, length, blob, blob_length);
@@ -527,7 +455,7 @@
 
 uint32_t Field_blob::pack_length() const
 {
-  return (uint32_t) (packlength+table->s->blob_ptr_size);
+  return (uint32_t) (sizeof(uint32_t)+table->s->blob_ptr_size);
 }
 
 void Field_blob::sql_type(String &res) const
@@ -550,7 +478,7 @@
     length given is smaller than the actual length of the blob, we
     just store the initial bytes of the blob.
   */
-  store_length(to, packlength, min(length, max_length), low_byte_first);
+  store_length(to, min(length, max_length), low_byte_first);
 
   /*
     Store the actual blob data, which will occupy 'length' bytes.
@@ -558,11 +486,11 @@
   if (length > 0)
   {
     get_ptr((unsigned char**) &from);
-    memcpy(to+packlength, from,length);
+    memcpy(to+sizeof(uint32_t), from,length);
   }
 
   ptr= save;					// Restore org row pointer
-  return(to+packlength+length);
+  return(to+sizeof(uint32_t)+length);
 }
 
 /**
@@ -584,16 +512,14 @@
 */
 const unsigned char *Field_blob::unpack(unsigned char *,
                                         const unsigned char *from,
-                                        uint32_t param_data,
+                                        uint32_t,
                                         bool low_byte_first)
 {
-  uint32_t const master_packlength=
-    param_data > 0 ? param_data & 0xFF : packlength;
-  uint32_t const length= get_length(from, master_packlength, low_byte_first);
+  uint32_t const length= get_length(from, low_byte_first);
   table->setWriteSet(field_index);
-  store(reinterpret_cast<const char*>(from) + master_packlength,
+  store(reinterpret_cast<const char*>(from) + sizeof(uint32_t),
         length, field_charset);
-  return(from + master_packlength + length);
+  return(from + sizeof(uint32_t) + length);
 }
 
 /** Create a packed key that will be used for storage from a MySQL row. */
@@ -631,18 +557,5 @@
 
 uint32_t Field_blob::max_display_length()
 {
-  switch (packlength)
-  {
-  case 1:
-    return 255 * field_charset->mbmaxlen;
-  case 2:
-    return 65535 * field_charset->mbmaxlen;
-  case 3:
-    return 16777215 * field_charset->mbmaxlen;
-  case 4:
     return (uint32_t) 4294967295U;
-  default:
-    assert(0); // we should never go here
-    return 0;
-  }
 }

=== modified file 'drizzled/field/blob.h'
--- drizzled/field/blob.h	2009-12-09 00:50:05 +0000
+++ drizzled/field/blob.h	2009-12-09 01:28:00 +0000
@@ -32,7 +32,6 @@
  */
 class Field_blob :public Field_str {
 protected:
-  uint32_t packlength;
   String value;				// For temporaries
 public:
 
@@ -58,8 +57,7 @@
                maybe_null_arg ? (unsigned char *) "": 0,
                0,
                field_name_arg,
-               cs),
-    packlength(4)
+               cs)
   {
     flags|= BLOB_FLAG;
   }
@@ -97,26 +95,24 @@
      @returns The length of the raw data itself without the pointer.
   */
   uint32_t pack_length_no_ptr() const
-  { return (uint32_t) (packlength); }
+  { return (uint32_t) (sizeof(uint32_t)); }
   uint32_t row_pack_length() { return pack_length_no_ptr(); }
   uint32_t sort_length() const;
   virtual uint32_t max_data_length() const
   {
-    return (uint32_t) (((uint64_t) 1 << (packlength*8)) -1);
+    return (uint32_t) (((uint64_t) 1 << 32) -1);
   }
-  int reset(void) { memset(ptr, 0, packlength+sizeof(unsigned char*)); return 0; }
+  int reset(void) { memset(ptr, 0, sizeof(uint32_t)+sizeof(unsigned char*)); return 0; }
   void reset_fields() { memset(&value, 0, sizeof(value)); }
 #ifndef WORDS_BIGENDIAN
   static
 #endif
-  void store_length(unsigned char *i_ptr, uint32_t i_packlength,
-                    uint32_t i_number, bool low_byte_first);
-  void store_length(unsigned char *i_ptr, uint32_t i_packlength,
-                    uint32_t i_number);
+  void store_length(unsigned char *i_ptr, uint32_t i_number, bool low_byte_first);
+  void store_length(unsigned char *i_ptr, uint32_t i_number);
 
   inline void store_length(uint32_t number)
   {
-    store_length(ptr, packlength, number);
+    store_length(ptr, number);
   }
 
   /**
@@ -130,28 +126,27 @@
   uint32_t get_packed_size(const unsigned char *ptr_arg, bool low_byte_first);
 
   uint32_t get_length(uint32_t row_offset= 0);
-  uint32_t get_length(const unsigned char *ptr, uint32_t packlength,
-                      bool low_byte_first);
+  uint32_t get_length(const unsigned char *ptr, bool low_byte_first);
   uint32_t get_length(const unsigned char *ptr_arg);
   void put_length(unsigned char *pos, uint32_t length);
   inline void get_ptr(unsigned char **str)
     {
-      memcpy(str,ptr+packlength,sizeof(unsigned char*));
+      memcpy(str,ptr+sizeof(uint32_t),sizeof(unsigned char*));
     }
   inline void get_ptr(unsigned char **str, uint32_t row_offset)
     {
-      memcpy(str,ptr+packlength+row_offset,sizeof(char*));
+      memcpy(str,ptr+sizeof(uint32_t)+row_offset,sizeof(char*));
     }
   inline void set_ptr(unsigned char *length, unsigned char *data)
     {
-      memcpy(ptr,length,packlength);
-      memcpy(ptr+packlength,&data,sizeof(char*));
+      memcpy(ptr,length,sizeof(uint32_t));
+      memcpy(ptr+sizeof(uint32_t),&data,sizeof(char*));
     }
   void set_ptr_offset(ptrdiff_t ptr_diff, uint32_t length, unsigned char *data)
     {
       unsigned char *ptr_ofs= ADD_TO_PTR(ptr,ptr_diff,unsigned char*);
-      store_length(ptr_ofs, packlength, length);
-      memcpy(ptr_ofs+packlength,&data,sizeof(char*));
+      store_length(ptr_ofs, length);
+      memcpy(ptr_ofs+sizeof(uint32_t),&data,sizeof(char*));
     }
   inline void set_ptr(uint32_t length, unsigned char *data)
     {
@@ -171,7 +166,7 @@
       return 1;
     }
     tmp=(unsigned char*) value.ptr();
-    memcpy(ptr+packlength,&tmp,sizeof(char*));
+    memcpy(ptr+sizeof(uint32_t),&tmp,sizeof(char*));
     return 0;
   }
   virtual unsigned char *pack(unsigned char *to, const unsigned char *from,
@@ -179,7 +174,7 @@
   unsigned char *pack_key(unsigned char *to, const unsigned char *from,
                   uint32_t max_length, bool low_byte_first);
   virtual const unsigned char *unpack(unsigned char *to, const unsigned char *from,
-                              uint32_t param_data, bool low_byte_first);
+                              uint32_t , bool low_byte_first);
   void free() { value.free(); }
   inline void clear_temporary() { memset(&value, 0, sizeof(value)); }
   friend int field_conv(Field *to,Field *from);

